@@ -16,18 +16,18 @@ except ImportError:
 time_types = (dt.date, dt.datetime)
 
 
-def reset_status_bar():
+def clean_up():
     """
-    Since Apple Script cannot access Excel while a Macro is running, we have to run the Python call in a
+    Since AppleScript cannot access Excel while a Macro is running, we have to run the Python call in a
     background process which makes the call return immediately: we rely on the StatusBar to give the user
     feedback.
-    This function is triggered when the interpreter exits and makes sure that the StatusBar in Excel is
-    reset. Due to a bug in Apple Script, False doesn't reset it properly so we're calling it through an
-    Excel Macro to get it right.
+    This function is triggered when the interpreter exits and runs the CleanUp Macro in VBA to show any
+    errors and to reset the StatusBar.
     """
-    app('Microsoft Excel').run_VB_macro('ResetStatusBar')
+    if is_excel_running():
+        app('Microsoft Excel').run_VB_macro('CleanUp')
 
-atexit.register(reset_status_bar)
+atexit.register(clean_up)
 
 
 def is_file_open(fullname):
@@ -69,10 +69,23 @@ def get_worksheet_name(xl_sheet):
     return xl_sheet.name.get()
 
 
+def get_xl_sheet(xl_workbook, sheet_name_or_index):
+    return xl_workbook.sheets[sheet_name_or_index]
+
+
+def set_worksheet_name(xl_sheet, value):
+    return xl_sheet.name.set(value)
+
+
 def get_worksheet_index(xl_sheet):
     return xl_sheet.entry_index.get()
 
 
+def get_app(xl_workbook):
+    # Since we can't have multiple instances of Excel on Mac (?), we ignore xl_workbook
+    return app('Microsoft Excel')
+
+
 def open_workbook(fullname):
     filename = os.path.basename(fullname)
     xl_app = app('Microsoft Excel')
@@ -98,7 +111,7 @@ def new_workbook():
         # It's a feature though: See p.14 on Excel 2004 AppleScript Reference
         xl_workbook = xl_app.make(new=kw.workbook)
     else:
-        xl_workbook = xl_app.active_workbook
+        xl_workbook = xl_app.workbooks[1]
 
     return xl_app, xl_workbook
 
@@ -248,4 +261,28 @@ def activate_chart(xl_chart):
     """
     activate() doesn't seem to do anything so resolving to select() for now
     """
-    xl_chart.select()
\ No newline at end of file
+    xl_chart.select()
+
+
+def autofit(range_, axis):
+    if (axis == 0 or axis == 'rows' or axis == 'r') and not range_.is_column():
+        range_.xl_range.rows.autofit()
+    elif (axis == 1 or axis == 'columns' or axis == 'c') and not range_.is_row():
+        range_.xl_range.columns.autofit()
+    elif axis is None:
+        if not range_.is_row():
+            range_.xl_range.columns.autofit()
+        if not range_.is_column():
+            range_.xl_range.rows.autofit()
+
+
+def set_xl_workbook_current(xl_workbook):
+    global xl_workbook_current
+    xl_workbook_current = xl_workbook
+
+
+def get_xl_workbook_current():
+    try:
+        return xl_workbook_current
+    except NameError:
+        return None
\ No newline at end of file
