@@ -11,7 +11,7 @@ License: BSD 3-clause (see LICENSE.txt for details)
 """
 import sys
 import numbers
-from . import PY3, xlplatform
+from . import xlplatform, string_types, time_types
 from .constants import ChartType
 
 # Optional imports
@@ -25,35 +25,31 @@ except ImportError:
     pd = None
 
 
-# Python 2 and 3 compatibility
-if PY3:
-    string_types = str
-else:
-    string_types = basestring
-
-# Platform compatibility
-time_types = xlplatform.time_types
-
-
 class Workbook(object):
     """
-    Workbook connects an Excel Workbook with Python. You can create a new connection from Python with
+    ``Workbook`` connects an Excel Workbook with Python. You can create a new connection from Python with
 
     * a new workbook: ``wb = Workbook()``
-    * an existing workbook: ``wb = Workbook(r'C:\\path\\to\\file.xlsx')``
+    * an unsaved workbook: ``wb = Workbook('Book1')``
+    * a saved workbook (open or closed): ``wb = Workbook(r'C:\\path\\to\\file.xlsx')``
 
-    If you want to create the connection from Excel through the xlwings VBA module, use:
+    To create a connection when the Python function is called through the Excel VBA module, use:
 
     ``wb = Workbook()``
 
-    Parameters
-    ----------
-    fullname : string, default None
-        If you want to connect to an existing Excel file from Python, use the fullname, e.g:
-        ``r'C:\\path\\to\\file.xlsx'``
+    When calling from VBA, always pack the ``Workbook`` call into the function being called from Excel, e.g.:
+
+    .. code-block:: python
+
+         def my_macro():
+            wb = Workbook()
+            Range('A1').value = 1
     """
-    def __init__(self, fullname=None):
-        if fullname:
+    def __init__(self, fullname=None, xl_workbook=None):
+        if xl_workbook:
+            self.xl_workbook = xl_workbook
+            self.xl_app = xlplatform.get_app(self.xl_workbook)
+        elif fullname:
             self.fullname = fullname.lower()
             if xlplatform.is_file_open(self.fullname):
                 # Connect to an open Workbook
@@ -61,7 +57,7 @@ class Workbook(object):
             else:
                 # Open Excel and the Workbook
                 self.xl_app, self.xl_workbook = xlplatform.open_workbook(self.fullname)
-        elif len(sys.argv) >= 2 and sys.argv[2] == 'from_xl':
+        elif len(sys.argv) > 2 and sys.argv[2] == 'from_xl':
             # Connect to the workbook from which this code has been invoked
             self.fullname = sys.argv[1].lower()
             self.xl_app, self.xl_workbook = xlplatform.get_workbook(self.fullname)
@@ -70,152 +66,122 @@ class Workbook(object):
             self.xl_app, self.xl_workbook = xlplatform.new_workbook()
 
         self.name = xlplatform.get_workbook_name(self.xl_workbook)
-        self.active_sheet = ActiveSheet(xl_workbook=self.xl_workbook)
+        self.active_sheet = Sheet.active(wkb=self)
 
         # Make the most recently created Workbook the default when creating Range objects directly
-        global xl_workbook_latest
-        xl_workbook_latest = self.xl_workbook
-
-    def activate(self, sheet):
+        xlplatform.set_xl_workbook_current(self.xl_workbook)
+        
+    @classmethod
+    def current(cls):
         """
-        Activates the given sheet.
-
-        Parameters
-        ----------
-        sheet : string or integer
-            Sheet name or index.
+        Returns the current Workbook object, i.e. the default Workbook used by ``Sheet``, ``Range`` and ``Chart`` if not
+        specified otherwise. On Windows, in case there are various instances of Excel running, opening an existing or
+        creating a new Workbook through ``Workbook()`` is acting on the same instance of Excel as this Workbook. Use
+        like this: ``Workbook.current()``.
         """
-        xlplatform.activate_sheet(self.xl_workbook, sheet)
+        return cls(xl_workbook=xlplatform.get_xl_workbook_current())
 
-    def get_selection(self, asarray=False):
+    def set_current(self):
         """
-        Returns the currently selected Range from Excel as xlwings Range object.
+        This makes the Workbook the default that ``Sheet``, ``Range`` and ``Chart`` use if not specified
+        otherwise. On Windows, in case there are various instances of Excel running, opening an existing or creating a
+        new Workbook through ``Workbook()`` is acting on the same instance of Excel as this Workbook.
+        """
+        xlplatform.set_xl_workbook_current(self.xl_workbook)
 
-        Parameters
-        ----------
+    def get_selection(self, asarray=False, atleast_2d=False):
+        """
+        Returns the currently selected cells from Excel as ``Range`` object.
+
+        Keyword Arguments
+        -----------------
         asarray : boolean, default False
             returns a NumPy array where empty cells are shown as nan
 
-        Returns
-        -------
-        xlwings Range object
-        """
-        return self.range(xlplatform.get_selection_address(self.xl_app), asarray=asarray)
-
-    def range(self, *args, **kwargs):
-        """
-        The range method gets and sets the Range object with the following arguments::
-
-            range('A1')          range('Sheet1', 'A1')          range(1, 'A1')
-            range('A1:C3')       range('Sheet1', 'A1:C3')       range(1, 'A1:C3')
-            range((1,2))         range('Sheet1, (1,2))          range(1, (1,2))
-            range((1,1), (3,3))  range('Sheet1', (1,1), (3,3))  range(1, (1,1), (3,3))
-            range('NamedRange')  range('Sheet1', 'NamedRange')  range(1, 'NamedRange')
-
-        If no worksheet name is provided as first argument (as name or index),
-        it will take the range from the active sheet.
-
-        Please check the available methods/properties directly under the Range object.
-
-        Parameters
-        ----------
-        asarray : boolean, default False
-            returns a NumPy array where empty cells are shown as nan
-
-        index : boolean, default True
-            Includes the index when setting a Pandas DataFrame
-
-        header : boolean, default True
-            Includes the column headers when setting a Pandas DataFrame
+        atleast_2d : boolean, default False
+            Returns 2d lists/arrays even if the Range is a Row or Column.
 
         Returns
         -------
-        Range
-            xlwings Range object
+        Range object
         """
-        return Range(*args, workbook=self.xl_workbook, **kwargs)
-
-    def chart(self, *args, **kwargs):
-        """
-        The chart method gives access to the chart object and can be called with the following arguments::
-
-            chart(1)            chart('Sheet1', 1)              chart(1, 1)
-            chart('Chart 1')    chart('Sheet1', 'Chart 1')      chart(1, 'Chart 1')
-
-        If no worksheet name is provided as first argument (as name or index),
-        it will take the Chart from the active sheet.
-
-        To insert a new Chart into Excel, create it as follows:
-
-        wb.chart().add()
-
-        Parameters
-        ----------
-        *args :
-            Definition of sheet (optional) and chart in the above described combinations.
-        """
-        return Chart(*args, workbook=self.xl_workbook, **kwargs)
-
-    def clear_contents(self, sheet=None):
-        """
-        Clears the content of a whole sheet but leaves the formatting.
-
-        Parameters
-        ----------
-        sheet : string or integer, default None
-            Sheet name or index. If sheet is None, the active sheet is used.
-        """
-        if sheet is None:
-            sheet = self.active_sheet.index
-
-        xlplatform.clear_contents_worksheet(self.xl_workbook, sheet)
-
-    def clear(self, sheet=None):
-        """
-        Clears the content and formatting of a whole sheet.
-
-        Parameters
-        ----------
-        sheet : string or integer, default None
-            Sheet name or index. If sheet is None, the active sheet is used.
-        """
-        if sheet is None:
-            sheet = self.active_sheet.index
-
-        xlplatform.clear_worksheet(self.xl_workbook, sheet)
+        return Range(xlplatform.get_selection_address(self.xl_app), wkb=self, asarray=asarray, atleast_2d=atleast_2d)
 
     def close(self):
-        """Closes the Workbook without saving it"""
+        """Closes the Workbook without saving it."""
         xlplatform.close_workbook(self.xl_workbook)
 
     def __repr__(self):
-        return "<xlwings.Workbook '{0}'>".format(self.name)
+        return "<Workbook '{0}'>".format(self.name)
 
 
-class ActiveSheet(object):
+class Sheet(object):
     """
-    Returns an object that represents the active sheet. Supposed to be used from the Workbook object like so::
+    Represents a Sheet of the current Workbook. Either call it with the Sheet name or index::
 
-        wb = Workbook()
-        wb.active_sheet.name
+        Sheet('Sheet1')
+        Sheet(1)
 
-    Parameters
-    ----------
-    xl_workbook : pywin32 or appscript object
-        Underlying Workbook object
+    Arguments
+    ---------
+    sheet : str or int
+        Sheet name or index
+
+    Keyword Arguments
+    -----------------
+    wkb : Workbook object, default Workbook.current()
+        Defaults to the Workbook that was instantiated last or set via ``Workbook.set_current()``.
     """
-    def __init__(self, xl_workbook=None):
-        if xl_workbook is None:
-            xl_workbook = xl_workbook_latest
-        self.xl_active_sheet = xlplatform.get_active_sheet(xl_workbook)
+
+    def __init__(self, sheet, wkb=None):
+        if wkb is None and xlplatform.get_xl_workbook_current() is None:
+            raise NameError('You must first instantiate a Workbook object.')
+        elif wkb is None:
+            self.xl_workbook = xlplatform.get_xl_workbook_current()
+        else:
+            self.xl_workbook = wkb.xl_workbook
+        self.sheet = sheet
+        self.xl_sheet = xlplatform.get_xl_sheet(self.xl_workbook, self.sheet)
+
+    def activate(self):
+        """Activates the sheet."""
+        xlplatform.activate_sheet(self.xl_workbook, self.sheet)
+
+    def clear_contents(self):
+        """Clears the content of the whole sheet but leaves the formatting."""
+        xlplatform.clear_contents_worksheet(self.xl_workbook, self.sheet)
+
+    def clear(self):
+        """Clears the content and formatting of the whole sheet."""
+        xlplatform.clear_worksheet(self.xl_workbook, self.sheet)
 
     @property
     def name(self):
-        return xlplatform.get_workbook_name(self.xl_active_sheet)
+        """Get or set the name of the Sheet."""
+        return xlplatform.get_worksheet_name(self.xl_sheet)
+
+    @name.setter
+    def name(self, value):
+        xlplatform.set_worksheet_name(self.xl_sheet, value)
 
     @property
     def index(self):
-        return xlplatform.get_worksheet_index(self.xl_active_sheet)
+        """Returns the index of the Sheet."""
+        return xlplatform.get_worksheet_index(self.xl_sheet)
+
+    @classmethod
+    def active(cls, wkb=None):
+        """Returns the active Sheet. Use like so: ``Sheet.active()``"""
+        if wkb is None and xlplatform.get_xl_workbook_current() is None:
+            raise NameError('You must first instantiate a Workbook object.')
+        elif wkb is None:
+            xl_workbook = xlplatform.get_xl_workbook_current()
+        else:
+            xl_workbook = wkb.xl_workbook
+        return cls(xlplatform.get_worksheet_name(xlplatform.get_active_sheet(xl_workbook)), wkb)
+
+    def __repr__(self):
+        return "<Sheet '{0}' of Workbook '{1}'>".format(self.name, xlplatform.get_workbook_name(self.xl_workbook))
 
 
 class Range(object):
@@ -233,10 +199,13 @@ class Range(object):
 
     You usually want to go for ``Range(...).value`` to get the values (as list of lists).
 
-    Parameters
-    ----------
+    Arguments
+    ---------
     *args :
         Definition of sheet (optional) and Range in the above described combinations.
+
+    Keyword Arguments
+    -----------------
     asarray : boolean, default False
         Returns a NumPy array (atleast_1d) where empty cells are transformed into nan.
 
@@ -248,6 +217,9 @@ class Range(object):
 
     atleast_2d : boolean, default False
         Returns 2d lists/arrays even if the Range is a Row or Column.
+
+    wkb : Workbook object, default Workbook.current()
+        Defaults to the Workbook that was instantiated last or set via `Workbook.set_current()``.
     """
     def __init__(self, *args, **kwargs):
         # Arguments
@@ -292,12 +264,18 @@ class Range(object):
 
         # Keyword Arguments
         self.kwargs = kwargs
+        self.workbook = kwargs.get('wkb', None)
+        if self.workbook is None and xlplatform.get_xl_workbook_current() is None:
+            raise NameError('You must first instantiate a Workbook object.')
+        elif self.workbook is None:
+            self.xl_workbook = xlplatform.get_xl_workbook_current()
+        else:
+            self.xl_workbook = self.workbook.xl_workbook
         self.index = kwargs.get('index', True)  # Set DataFrame with index
         self.header = kwargs.get('header', True)  # Set DataFrame with header
         self.asarray = kwargs.get('asarray', False)  # Return Data as NumPy Array
         self.strict = kwargs.get('strict', False)  # Stop table/horizontal/vertical at empty cells that contain formulas
         self.atleast_2d = kwargs.get('atleast_2d', False)  # Force data to be list of list or a 2d numpy array
-        self.xl_workbook = kwargs.get('workbook', xl_workbook_latest)
 
         # Get sheet
         if sheet_name_or_index:
@@ -316,7 +294,7 @@ class Range(object):
 
     def is_cell(self):
         """
-        Returns True if the Range consists of a single Cell otherwise False
+        Returns ``True`` if the Range consists of a single Cell otherwise ``False``.
         """
         if self.row1 == self.row2 and self.col1 == self.col2:
             return True
@@ -325,7 +303,7 @@ class Range(object):
 
     def is_row(self):
         """
-        Returns True if the Range consists of a single Row otherwise False
+        Returns ``True`` if the Range consists of a single Row otherwise ``False``.
         """
         if self.row1 == self.row2 and self.col1 != self.col2:
             return True
@@ -334,7 +312,7 @@ class Range(object):
 
     def is_column(self):
         """
-        Returns True if the Range consists of a single Column otherwise False
+        Returns ``True`` if the Range consists of a single Column otherwise ``False``.
         """
         if self.row1 != self.row2 and self.col1 == self.col2:
             return True
@@ -343,7 +321,7 @@ class Range(object):
 
     def is_table(self):
         """
-        Returns True if the Range consists of a 2d array otherwise False
+        Returns ``True`` if the Range consists of a 2d array otherwise ``False``.
         """
         if self.row1 != self.row2 and self.col1 != self.col2:
             return True
@@ -358,13 +336,15 @@ class Range(object):
         Returns
         -------
         list or numpy array
-            Empty cells are set to None. If ``asarray=True``,
-            a numpy array is returned where empty cells are set to nan.
+            Empty cells are set to ``None``. If ``asarray=True``,
+            a numpy array is returned where empty cells are set to ``nan``.
         """
         # TODO: refactor
         if self.is_cell():
             # Clean_xl_data requires and returns a list of list
-            data = xlplatform.clean_xl_data([[xlplatform.get_value_from_range(self.xl_range)]])[0][0]
+            data = xlplatform.clean_xl_data([[xlplatform.get_value_from_range(self.xl_range)]])
+            if not self.atleast_2d:
+                data = data[0][0]
         elif self.is_row():
             data = xlplatform.clean_xl_data(xlplatform.get_value_from_range(self.xl_range))
             if not self.atleast_2d:
@@ -478,14 +458,15 @@ class Range(object):
         Returns a contiguous Range starting with the indicated cell as top-left corner and going down and right as
         long as no empty cell is hit.
 
-        Parameters
-        ----------
+        Keyword Arguments
+        -----------------
         strict : boolean, default False
-            strict stops the table at empty cells even if they contain a formula. Less efficient than if set to False.
+            ``True`` stops the table at empty cells even if they contain a formula. Less efficient than if set to
+            ``False``.
 
         Returns
         -------
-        xlwings Range object
+        Range object
 
         Examples
         --------
@@ -507,16 +488,17 @@ class Range(object):
     def vertical(self):
         """
         Returns a contiguous Range starting with the indicated cell and going down as long as no empty cell is hit.
-        This corresponds to ``Ctrl + Shift + Down Arrow`` in Excel.
+        This corresponds to ``Ctrl-Shift-DownArrow`` in Excel.
 
-        Parameters
-        ----------
+        Arguments
+        ---------
         strict : bool, default False
-            strict stops the table at empty cells even if they contain a formula. Less efficient than if set to False.
+            ``True`` stops the table at empty cells even if they contain a formula. Less efficient than if set to
+            ``False``.
 
         Returns
         -------
-        xlwings Range object
+        Range object
 
         Examples
         --------
@@ -548,18 +530,19 @@ class Range(object):
         """
         Returns a contiguous Range starting with the indicated cell and going right as long as no empty cell is hit.
 
-        Parameters
-        ----------
+        Keyword Arguments
+        -----------------
         strict : bool, default False
-            strict stops the table at empty cells even if they contain a formula. Less efficient than if set to False.
+            ``True`` stops the table at empty cells even if they contain a formula. Less efficient than if set to
+            ``False``.
 
         Returns
         -------
-        xlwings Range object
+        Range object
 
         Examples
         --------
-        To get the values of a contiguous range or clear its contents use::
+        To get the values of a contiguous Range or clear its contents use::
 
             Range('A1').horizontal.value
             Range('A1').horizontal.clear_contents()
@@ -585,12 +568,13 @@ class Range(object):
     @property
     def current_region(self):
         """
-        The current_region property returns a Range object representing a range bounded by (but not including) any
-        combination of blank rows and blank columns or the edges of the worksheet. It corresponds to ``Ctrl + *``.
+        This property returns a Range object representing a range bounded by (but not including) any
+        combination of blank rows and blank columns or the edges of the worksheet. It corresponds to ``Ctrl-*`` on
+        Windows and ``Shift-Ctrl-Space`` on Mac.
 
         Returns
         -------
-        xlwings Range object
+        Range object
 
         """
         address = xlplatform.get_current_region_address(self.xl_sheet, self.row1, self.col1)
@@ -608,52 +592,97 @@ class Range(object):
         """
         xlplatform.clear_contents_range(self.xl_range)
 
+    def autofit(self, axis=None):
+        """
+        Autofits the width of either columns, rows or both.
+
+        Arguments
+        ---------
+        axis : string or integer, default None
+            - To autofit rows, use one of the following: 0 or ``rows`` or ``r``
+            - To autofit columns, use one of the following: 1 or ``columns`` or ``c``
+            - To autofit rows and columns, provide no arguments
+
+        Examples
+        --------
+        ::
+
+            # Autofit column A
+            Range('A:A').autofit()
+            # Autofit row 1
+            Range('1:1').autofit()
+            # Autofit columns and rows, taking into account Range('A1:E4')
+            Range('A1:E4').autofit()
+            # AutoFit columns, taking into account Range('A1:E4')
+            Range('A1:E4').autofit(axis=1)
+            # AutoFit rows, taking into account Range('A1:E4')
+            Range('A1:E4').autofit('rows')
+
+        """
+        xlplatform.autofit(self, axis)
+
     def __repr__(self):
-        return "<xlwings.Range of Workbook '{0}'>".format(xlplatform.get_workbook_name(self.xl_workbook))
+        return "<Range on Sheet '{0}' of Workbook '{1}'>".format(xlplatform.get_worksheet_name(self.xl_sheet),
+                                                                 xlplatform.get_workbook_name(self.xl_workbook))
 
 
 class Chart(object):
     """
-    A chart object that represents an existing Excel chart can be created with the following arguments::
+    A Chart object that represents an existing Excel chart can be created with the following arguments::
 
         Chart(1)            Chart('Sheet1', 1)              Chart(1, 1)
         Chart('Chart 1')    Chart('Sheet1', 'Chart 1')      Chart(1, 'Chart 1')
 
-    If no worksheet name is provided as first argument (as name or index),
-    it will take the chart from the active sheet.
+    If no Worksheet is provided as first argument (as name or index),
+    it will take the Chart from the active Sheet.
 
-    To insert a new chart into Excel, create it as follows::
+    To insert a new Chart into Excel, create it as follows::
 
-        Chart().add()
+        Chart.add()
 
-    Parameters
-    ----------
+    Arguments
+    ---------
     *args
-        Definition of sheet (optional) and chart in the above described combinations.
+        Definition of Sheet (optional) and chart in the above described combinations.
 
-    chart_type : Member of ChartType, default xlColumnClustered
-        Chart type, can also be set using the ``chart_type`` property
+    Keyword Arguments
+    -----------------
+    wkb : Workbook object, default Workbook.current()
+        Defaults to the Workbook that was instantiated last or set via ``Workbook.set_current()``.
+
+    Example
+    -------
+    >>> from xlwings import Workbook, Range, Chart, ChartType
+    >>> wb = Workbook()
+    >>> Range('A1').value = [['Foo1', 'Foo2'], [1, 2]]
+    >>> chart = Chart.add(source_data=Range('A1').table, chart_type=ChartType.xlLine)
+    >>> chart.name
+    u'Chart1'
+    >>> chart.chart_type = ChartType.xl3DArea
 
     """
     def __init__(self, *args, **kwargs):
         # Use global Workbook if none provided
-        self.xl_workbook = kwargs.get('workbook', xl_workbook_latest)
+        self.workbook = kwargs.get('wkb', None)
+        if self.workbook is None and xlplatform.get_xl_workbook_current() is None:
+            raise NameError('You must first instantiate a Workbook object.')
+        elif self.workbook is None:
+            self.xl_workbook = xlplatform.get_xl_workbook_current()
+        else:
+            self.xl_workbook = self.workbook.xl_workbook
 
         # Arguments
-        if len(args) == 0:
-            pass
-        elif len(args) > 0:
-            if len(args) == 1:
-                _sheet_name_or_index = xlplatform.get_worksheet_name(xlplatform.get_active_sheet(self.xl_workbook))
-                _name_or_index = args[0]
-            elif len(args) == 2:
-                _sheet_name_or_index = args[0]
-                _name_or_index = args[1]
+        if len(args) == 1:
+            self.sheet_name_or_index = xlplatform.get_worksheet_name(xlplatform.get_active_sheet(self.xl_workbook))
+            self.name_or_index = args[0]
+        elif len(args) == 2:
+            self.sheet_name_or_index = args[0]
+            self.name_or_index = args[1]
 
-            # Get xl_chart object
-            self.xl_chart = xlplatform.get_chart_object(self.xl_workbook, _sheet_name_or_index, _name_or_index)
-            self.index = xlplatform.get_chart_index(self.xl_chart)
-            self.name = xlplatform.get_chart_name(self.xl_chart)
+        # Get xl_chart object
+        self.xl_chart = xlplatform.get_chart_object(self.xl_workbook, self.sheet_name_or_index, self.name_or_index)
+        self.index = xlplatform.get_chart_index(self.xl_chart)
+        self.name = xlplatform.get_chart_name(self.xl_chart)
 
         # Chart Type
         chart_type = kwargs.get('chart_type')
@@ -665,14 +694,15 @@ class Chart(object):
         if source_data:
             self.set_source_data(source_data)
 
-    def add(self, sheet=None, left=168, top=217, width=355, height=211, **kwargs):
+    @classmethod
+    def add(cls, sheet=None, left=168, top=217, width=355, height=211, **kwargs):
         """
-        Inserts a new chart in Excel.
+        Inserts a new Chart in Excel.
 
         Arguments
         ---------
         sheet : string or integer, default None
-            Name or Index of the sheet, defaults to the active sheet
+            Name or index of the Sheet, defaults to the active Sheet
 
         left : float, default 100
             left position in points
@@ -686,36 +716,46 @@ class Chart(object):
         height : float, default 225
             height in points
 
+        Keyword Arguments
+        -----------------
         chart_type : xlwings.ChartType member, default xlColumnClustered
             Excel chart type. E.g. xlwings.ChartType.xlLine
 
         name : str, default None
             Excel chart name. Defaults to Excel standard name if not provided, e.g. 'Chart 1'
 
-        source_data : xlwings Range
+        source_data : Range
             e.g. Range('A1').table
 
+        wkb : Workbook object, default Workbook.current()
+            Defaults to the Workbook that was instantiated last or set via ``Workbook.set_current()``.
         """
+        workbook = kwargs.get('wkb', None)
+        if workbook is None:
+            xl_workbook = xlplatform.get_xl_workbook_current()
+        else:
+            xl_workbook = workbook.xl_workbook
+
         chart_type = kwargs.get('chart_type', ChartType.xlColumnClustered)
         name = kwargs.get('name')
         source_data = kwargs.get('source_data')
 
         if sheet is None:
-            sheet = xlplatform.get_worksheet_index(xlplatform.get_active_sheet(self.xl_workbook))
+            sheet = xlplatform.get_worksheet_index(xlplatform.get_active_sheet(xl_workbook))
 
-        xl_chart = xlplatform.add_chart(self.xl_workbook, sheet, left, top, width, height)
+        xl_chart = xlplatform.add_chart(xl_workbook, sheet, left, top, width, height)
 
         if name:
             xlplatform.set_chart_name(xl_chart, name)
         else:
             name = xlplatform.get_chart_name(xl_chart)
 
-        return Chart(sheet, name, workbook=self.xl_workbook, chart_type=chart_type, source_data=source_data)
+        return cls(sheet, name, wkb=workbook, chart_type=chart_type, source_data=source_data)
 
     @property
     def name(self):
         """
-        Gets and sets the name of a chart
+        Gets and sets the name of a chart.
         """
         return xlplatform.get_chart_name(self.xl_chart)
 
@@ -726,7 +766,7 @@ class Chart(object):
     @property
     def chart_type(self):
         """
-        Gets and sets the chart type of a chart
+        Gets and sets the chart type of a chart.
         """
         return xlplatform.get_chart_type(self.xl_chart)
 
@@ -742,15 +782,17 @@ class Chart(object):
 
     def set_source_data(self, source):
         """
-        Sets the source for the chart
+        Sets the source for the chart.
 
         Arguments
         ---------
         source : Range
-            xlwings Range object, e.g. ``Range('A1')``
+            Range object, e.g. ``Range('A1')``
         """
         xlplatform.set_source_data_chart(self.xl_chart, source.xl_range)
 
     def __repr__(self):
-        return "<xlwings.Chart '{0}'>".format(self.name)
+        return "<Chart '{0}' on Sheet '{1}' of Workbook '{2}'>".format(self.name,
+                                                                       Sheet(self.sheet_name_or_index).name,
+                                                                       xlplatform.get_workbook_name(self.xl_workbook))
 
